@@ -19,7 +19,15 @@ from datetime import datetime
 
 # Xport Modules
 import xport.v56
-from xport.v56 import strftime, text_encode
+from xport.v56 import _encoding, strftime, text_encode
+
+__all__ = [
+    'load',
+    'loads',
+    'dump',
+    'dumps',
+    '_encoding',
+]
 
 LOG = logging.getLogger(__name__)
 
@@ -82,18 +90,16 @@ class MemberHeader(xport.v56.MemberHeader):
             number, name_length, label_length = struct.unpack('>hhh', data[:6])
             i = (10 if v9 else 6) + name_length
             j = i + label_length
-            namestrs[number].name = data[6:i].decode('ISO-8859-1')
-            namestrs[number].label = data[i:j].decode('ISO-8859-1')
+            namestrs[number].name = data[6:i].decode(xport.v56.TEXT_METADATA_ENCODING)
+            namestrs[number].label = data[i:j].decode(xport.v56.TEXT_METADATA_ENCODING)
             if v9:
                 format_length, informat_length = struct.unpack('>hh', data[6:10])
             data = data[j:]
             if v9:
                 i = format_length
                 j = i + informat_length
-                namestrs[number].format = xport.Format.from_spec(data[:i].decode('ISO-8859-1'))
-                namestrs[number].informat = xport.Informat.from_spec(
-                    data[i:j].decode('ISO-8859-1')
-                )
+                namestrs[number].format = xport.Format.from_spec(data[:i].decode('ascii'))
+                namestrs[number].informat = xport.Informat.from_spec(data[i:j].decode('ascii'))
                 data = data[j:]
         if data and set(data) != {ord(b' ')}:
             raise ValueError(f'Expected only padding, got {data}')
@@ -136,9 +142,10 @@ HEADER RECORD{'*' * 7}OBSV8   HEADER RECORD{'!' * 7}{'0' * 30}  \
         triggers = {'label': 40}  # , 'format': 8, 'informat': 8}
         for namestr in self.values():
             strings = {
-                'name': namestr.name.encode('ascii'),
-                'label': (namestr.label if namestr.label is not None else '').encode('ascii'),
+                'name': namestr.name,
+                'label': namestr.label if namestr.label is not None else '',
             }
+            strings = {k: v.encode(xport.v56.TEXT_METADATA_ENCODING) for k, v in strings.items()}
             if any(len(strings[k]) > l for k, l in triggers.items()):
                 strings = list(strings.values())
                 fmt = '>hhh' + ''.join(f'{len(s)}s' for s in strings)
@@ -152,7 +159,7 @@ HEADER RECORD{'*' * 7}OBSV8   HEADER RECORD{'!' * 7}{'0' * 30}  \
             b'label': text_encode(self, 'dataset_label', 40),
             b'type': text_encode(self, 'dataset_type', 8),
             b'n_variables': len(self),
-            b'n_labels': str(n_labels or '').ljust(5).encode('ascii'),
+            b'n_labels': str(n_labels or '').ljust(5).encode(xport.v56.TEXT_METADATA_ENCODING),
             b'os': text_encode(self, 'sas_os', 8),
             b'version': text_encode(self, 'sas_version', 8),
             b'created': strftime(self.created if self.created else datetime.now()),
@@ -203,7 +210,8 @@ class Namestr(xport.v56.Namestr):
         v56 = super().from_bytes(bytestring)
         fmt = cls.fmts[len(bytestring)]
         tokens = struct.unpack(fmt, bytestring)
-        longname = tokens[-3].strip(b'\x00').decode('ISO-8859-1').rstrip() or v56.name
+        longname = tokens[-3].strip(b'\x00').decode(xport.v56.TEXT_METADATA_ENCODING
+                                                    ).rstrip() or v56.name
         if v56.name not in longname:
             warnings.warn(f'Short name {v56.name} not included in {longname}')
         # TODO: What should I do with the label length?  ``tokens[-2]``
@@ -228,7 +236,9 @@ class Namestr(xport.v56.Namestr):
         longname = text_encode(self, 'name', 32)
         shortname = longname[:8]
 
-        longlabel = (self.label if self.label is not None else '').encode('ascii')
+        longlabel = (self.label if self.label is not None else '').encode(
+            xport.v56.TEXT_METADATA_ENCODING
+        )
         if len(longlabel) > 256:
             raise ValueError('ASCII-encoded label {longlabel} exceeds 256 characters')
         shortlabel = longlabel[:40].ljust(40)
